package org.apache.bcel.generic;

import java.io.DataOutputStream;
import java.io.IOException;
import org.apache.bcel.util.ByteSequence;

/* loaded from: org_apache_bcel_generic.jar:org/apache/bcel/generic/RET.class */
public class RET extends Instruction implements IndexedInstruction, TypedInstruction {
    private boolean wide;
    private int index;

    /* JADX INFO: Access modifiers changed from: package-private */
    public RET() {
    }

    public RET(int index) {
        super((short) 169, (short) 2);
        setIndex(index);
    }

    @Override // org.apache.bcel.generic.Instruction
    public void accept(Visitor v) {
        v.visitRET(this);
    }

    @Override // org.apache.bcel.generic.Instruction
    public void dump(DataOutputStream out) throws IOException {
        if (this.wide) {
            out.writeByte(196);
        }
        out.writeByte(super.getOpcode());
        if (this.wide) {
            out.writeShort(this.index);
        } else {
            out.writeByte(this.index);
        }
    }

    @Override // org.apache.bcel.generic.IndexedInstruction
    public final int getIndex() {
        return this.index;
    }

    @Override // org.apache.bcel.generic.TypedInstruction
    public Type getType(ConstantPoolGen cp) {
        return ReturnaddressType.NO_TARGET;
    }

    @Override // org.apache.bcel.generic.Instruction
    protected void initFromFile(ByteSequence bytes, boolean wide) throws IOException {
        this.wide = wide;
        if (wide) {
            this.index = bytes.readUnsignedShort();
            super.setLength(4);
        } else {
            this.index = bytes.readUnsignedByte();
            super.setLength(2);
        }
    }

    @Override // org.apache.bcel.generic.IndexedInstruction
    public final void setIndex(int n) {
        if (n < 0) {
            throw new ClassGenException("Negative index value: " + n);
        }
        this.index = n;
        setWide();
    }

    private void setWide() {
        this.wide = this.index > 255;
        if (this.wide) {
            super.setLength(4);
        } else {
            super.setLength(2);
        }
    }

    @Override // org.apache.bcel.generic.Instruction
    public String toString(boolean verbose) {
        return super.toString(verbose) + " " + this.index;
    }
}
